@@ -30,4 +30,4 @@
 # p.set("a", "b", "c")
 
 
-from sklearn.feature_extraction.text import HashingVectorizer
+# from sklearn.feature_extraction.text import HashingVectorizer
