@@ -15,7 +15,7 @@ https://blog.csdn.net/foreseerwang/article/details/80572182
 """
 import tensorflow as tf
 from tql.pipe import *
-from tql.algo_nlp.utils import Text2Sequence
+from tql.nlp.utils import Text2Sequence
 from tql.algo_dl.keras.utils import DataIter
 from tql.algo_dl.keras.models import TextCNN, TextFast
 
