@@ -10,7 +10,7 @@
 
 
 from tql.pipe import *
-from tql.algo_nlp.utils import Text2SequenceByFastText
+from tql.nlp.utils import Text2SequenceByFastText
 from tql.algo_dl.keras.utils import DataIter
 from tql.algo_dl.keras.models import TextCNN
 from gensim.models.fasttext import load_facebook_model
