@@ -35,7 +35,7 @@ def duplicate_columns(frame):
         ks = list(dcols.keys())
         lvs = len(vs)
 
-        for i in tqdm(range(lvs), desc=str(t)):
+        for i in range(lvs):
             for j in range(i + 1, lvs):
                 if vs[i] == vs[j]:
                     dups.append(ks[j])  # keep='first'
